@@ -1,5 +1,6 @@
 import datetime
 
+from math import ceil
 from tcell_agent.agent import TCellAgent
 from tcell_agent.instrumentation.decorators import catches_generic_exception
 from tcell_agent.tcell_logger import get_module_logger
@@ -14,7 +15,7 @@ def get_current_time():
 def end_timer(request):
     if request._tcell_context.start_time != 0:
         endtime = get_current_time()
-        request_time = int((endtime - request._tcell_context.start_time).total_seconds() * 1000)
+        request_time = int(ceil((endtime - request._tcell_context.start_time).total_seconds() * 1000))
         TCellAgent.request_metric(
             request._tcell_context.route_id,
             request_time,
