@@ -1,4 +1,17 @@
 from tcell_agent.global_state import django_active, flask_active
+from tcell_agent.config.configuration import get_config
+
+
+def module_name(module):
+    if hasattr(module, "__name__"):
+        return module.__name__.replace("__", "").replace("builtins", "builtin")
+
+    return ""
+
+
+def skip_instrumentation(module, original_method_str):
+    key = "{}.{}".format(module, original_method_str)
+    return key in get_config().disabled_instrumentation
 
 
 def get_tcell_context():
