@@ -13,7 +13,7 @@ class HttpRedirectRequest(dict):
         self["method"] = tcell_context.method
         self["path"] = tcell_context.path
         self["remote_addr"] = tcell_context.remote_address
-        self["full_uri"] = tcell_context.fullpath
+        self["full_uri"] = tcell_context.uri
         self["route_id"] = tcell_context.route_id
         self["session_id"] = tcell_context.session_id
         self["user_id"] = tcell_context.user_id
