@@ -37,6 +37,9 @@ class ConfigurationBuilder(object):
         self.configuration.js_agent_url = "https://us.jsagent.tcell.insight.rapid7.com/tcellagent.min.js"
         self.configuration.reverse_proxy = True
 
+        from tcell_agent.global_state import set_after_agent_started_instrumentation
+        set_after_agent_started_instrumentation()  # disables LFI/OS instrumentation
+
     def update_attribute(self, attribute, setting):
         setattr(self.configuration, attribute, setting)
         return self
